"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from friendli.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class TokenSequenceTypedDict(TypedDict):
    tokens: NotRequired[List[int]]
    r"""A List of token IDs."""


class TokenSequence(BaseModel):
    tokens: Optional[List[int]] = None
    r"""A List of token IDs."""
