"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from friendli.types import BaseModel
from typing import Literal, Optional
from typing_extensions import NotRequired, TypedDict


Role = Literal["system"]
r"""The role of the messages author."""


class SystemMessageTypedDict(TypedDict):
    role: Role
    r"""The role of the messages author."""
    content: str
    r"""The content of system message."""
    name: NotRequired[str]
    r"""The name for the participant to distinguish between participants with the same role."""


class SystemMessage(BaseModel):
    role: Role
    r"""The role of the messages author."""

    content: str
    r"""The content of system message."""

    name: Optional[str] = None
    r"""The name for the participant to distinguish between participants with the same role."""
