"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from friendli.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


ResponseFormatTextType = Literal["text"]
r"""The type of the response format: `text`"""


class ResponseFormatTextTypedDict(TypedDict):
    type: ResponseFormatTextType
    r"""The type of the response format: `text`"""


class ResponseFormatText(BaseModel):
    type: ResponseFormatTextType
    r"""The type of the response format: `text`"""
