"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .completionsbodywithprompt import (
    CompletionsBodyWithPrompt,
    CompletionsBodyWithPromptTypedDict,
)
from .completionsbodywithtokens import (
    CompletionsBodyWithTokens,
    CompletionsBodyWithTokensTypedDict,
)
from typing import Union
from typing_extensions import TypeAliasType


ServerlessCompletionsCompleteBodyTypedDict = TypeAliasType(
    "ServerlessCompletionsCompleteBodyTypedDict",
    Union[CompletionsBodyWithPromptTypedDict, CompletionsBodyWithTokensTypedDict],
)


ServerlessCompletionsCompleteBody = TypeAliasType(
    "ServerlessCompletionsCompleteBody",
    Union[CompletionsBodyWithPrompt, CompletionsBodyWithTokens],
)
